@@ -120,6 +120,12 @@ class CLIParser:
             required=False,
             help="values in '.env' file override values in the environment",
         )
+        parser.add_argument(
+            "--print-pid",
+            action="store_true",
+            required=False,
+            help="include the process ID of this CLI invocation alongside timestamp in logging messages",
+        )
 
         # Module-specific argument sets
         if not any(module in sys.argv[0] for module in ["compare"]):
@@ -624,6 +630,13 @@ class CLIParser:
                 required=False,
                 help="list user attribute definitions",
             )
+            parser.add_argument(
+                "--namespaces",
+                "-M",
+                action="store_true",
+                required=False,
+                help="list namespaces",
+            )
             parser.add_argument(
                 "--namespace-policies",
                 "-P",
@@ -1275,6 +1288,11 @@ class CLIParser:
     def env_override(self) -> Optional[bool]:
         return self.args.env_override
 
+    @property
+    @allow_missing_attribute
+    def print_pid(self) -> Optional[bool]:
+        return self.args.print_pid
+
     @property
     @allow_missing_attribute
     def work_req_file(self) -> Optional[str]:
@@ -1578,6 +1596,11 @@ class CLIParser:
     def attribute_definitions(self) -> Optional[bool]:
         return self.args.attribute_definitions
 
+    @property
+    @allow_missing_attribute
+    def namespaces(self) -> Optional[bool]:
+        return self.args.namespaces
+
     @property
     @allow_missing_attribute
     def namespace_policies(self) -> Optional[bool]:
