@@ -25,6 +25,7 @@ from yellowdog_client.model import (
     MachineImageFamily,
     MachineImageFamilySearch,
     MachineImageFamilySummary,
+    NamespaceSearch,
     ObjectPath,
     ObjectPathsRequest,
     ProvisionedWorkerPool,
@@ -528,6 +529,33 @@ def substitute_ids_for_names_in_crt(
     return crt
 
 
+def substitute_image_family_id_for_name_in_cst(
+    client: PlatformClient, cst: ComputeSourceTemplate
+) -> ComputeSourceTemplate:
+    """
+    Substitute Image Family IDs for namespace/name,
+    if option is selected.
+    """
+
+    if not ARGS_PARSER.substitute_ids:
+        return cst
+
+    try:
+        cst.source.imageId = _get_image_family_name_from_id(client, cst.source.imageId)
+        return cst
+    except:
+        pass
+
+    try:
+        # Google uses a different property name
+        cst.source.image = _get_image_family_name_from_id(client, cst.source.image)
+        return cst
+    except:
+        pass
+
+    return cst
+
+
 @lru_cache
 def _get_source_template_name_from_id(
     client: PlatformClient, cst_id: Optional[str]
@@ -574,8 +602,11 @@ def get_role_id_by_name(client: PlatformClient, role_name: str) -> Optional[str]
     if get_ydid_type(role_name) == YDIDType.ROLE:
         return role_name
 
-    for role in get_all_roles(client):
-        if role_name == role.name:
+    role_search = RoleSearch(name=role_name)
+    search_client: SearchClient = client.account_client.get_roles(role_search)
+
+    for role in search_client.list_all():
+        if role.name == role_name:
             return role.id
 
     return None
@@ -606,8 +637,11 @@ def get_all_roles(client: PlatformClient) -> List[RoleSummary]:
 @lru_cache
 def get_group_id_by_name(client: PlatformClient, group_name: str) -> Optional[str]:
     """
-    Get a group's ID by its name.
+    Get a group's ID by its name. Accept IDs and return unchanged.
     """
+    if get_ydid_type(group_name) == YDIDType.GROUP:
+        return group_name
+
     group_search = GroupSearch(name=group_name)
     search_client: SearchClient = client.account_client.get_groups(group_search)
     group_summaries: List[GroupSummary] = search_client.list_all()
@@ -641,6 +675,15 @@ def get_all_groups(client: PlatformClient) -> List[GroupSummary]:
     return search_client.list_all()
 
 
+def clear_group_caches():
+    """
+    Clear the group caches.
+    """
+    get_all_groups.cache_clear()
+    get_group_name_by_id.cache_clear()
+    get_group_id_by_name.cache_clear()
+
+
 @lru_cache
 def get_all_applications(client: PlatformClient) -> List[Application]:
     """
@@ -656,8 +699,11 @@ def get_all_applications(client: PlatformClient) -> List[Application]:
 @lru_cache
 def get_application_id_by_name(client: PlatformClient, app_name: str) -> Optional[str]:
     """
-    Get an application ID by its name.
+    Get an application ID by its name. Accept IDs and return unchanged.
     """
+    if get_ydid_type(app_name) == YDIDType.APPLICATION:
+        return app_name
+
     for app in get_all_applications(client):
         if app.name == app_name:
             return app.id
@@ -665,6 +711,14 @@ def get_application_id_by_name(client: PlatformClient, app_name: str) -> Optiona
     return None
 
 
+def clear_application_caches():
+    """
+    Clear the application caches.
+    """
+    get_all_applications.cache_clear()
+    get_application_id_by_name.cache_clear()
+
+
 def get_application_groups(client: PlatformClient, app_id: str) -> List[GroupSummary]:
     """
     Get the groups to which an application belongs.
@@ -679,20 +733,22 @@ def get_user_groups(client: PlatformClient, user_id: str) -> List[GroupSummary]:
     return client.account_client.get_user_groups(user_id).list_all()
 
 
+@lru_cache
 def get_user_by_name_or_id(
     client: PlatformClient, user_name_or_id: str
 ) -> Optional[User]:
     """
-    Get a user ID by their username or ID.
+    Get a user ID by name, username or ID.
     """
     for user in get_all_users(client):
 
         if user.id == user_name_or_id:
             return user
 
-        if (isinstance(user, InternalUser) and user.username == user_name_or_id) or (
-            isinstance(user, ExternalUser) and user.name == user_name_or_id
-        ):
+        if (
+            isinstance(user, InternalUser)
+            and (user.username == user_name_or_id or user.name == user_name_or_id)
+        ) or (isinstance(user, ExternalUser) and user.name == user_name_or_id):
             return user
 
     return None
@@ -706,3 +762,19 @@ def get_all_users(client: PlatformClient) -> List[User]:
     user_search = UserSearch()
     search_client: SearchClient = client.account_client.get_users(user_search)
     return search_client.list_all()
+
+
+def get_namespace_id_by_name(
+    client: PlatformClient, namespace_name: str
+) -> Optional[str]:
+    """
+    Get a namespace's ID by its name.
+    """
+    search_client: SearchClient = client.namespaces_client.get_namespaces(
+        NamespaceSearch(namespace_name)
+    )
+    for namespace in search_client.list_all():
+        if namespace.namespace == namespace_name:
+            return namespace.id
+
+    return None
