@@ -118,9 +118,12 @@ RN_ALLOWANCE = "Allowance"
 RN_APPLICATION = "Application"
 RN_CONFIGURED_POOL = "ConfiguredWorkerPool"
 RN_CREDENTIAL = "Credential"
+RN_EXTERNAL_USER = "ExternalUser"
 RN_GROUP = "Group"
 RN_IMAGE_FAMILY = "MachineImageFamily"
+RN_INTERNAL_USER = "InternalUser"
 RN_KEYRING = "Keyring"
+RN_NAMESPACE = "Namespace"
 RN_NAMESPACE_POLICY = "NamespacePolicy"
 RN_NUMERIC_ATTRIBUTE_DEFINITION = "NumericAttributeDefinition"
 RN_REQUIREMENT_TEMPLATE = "ComputeRequirementTemplate"
@@ -130,7 +133,6 @@ RN_STORAGE_CONFIGURATION = "NamespaceStorageConfiguration"
 RN_STRING_ATTRIBUTE_DEFINITION = "StringAttributeDefinition"
 RN_UPDATE_APPLICATION_REQUEST = "UpdateApplicationRequest"
 RN_UPDATE_GROUP_REQUEST = "UpdateGroupRequest"
-RN_USER = "User"
 
 # Property Names
 PROP_ACCESS_DELEGATES = "accessDelegates"
@@ -141,6 +143,7 @@ PROP_CREATED_TIME = "createdTime"
 PROP_CREDENTIAL = "credential"
 PROP_CST_ID = "sourceTemplateId"
 PROP_DEFAULT_RANK_ORDER = "defaultRankOrder"
+PROP_DELETABLE = "deletable"
 PROP_DESCRIPTION = "description"
 PROP_EFFECTIVE_FROM = "effectiveFrom"
 PROP_EFFECTIVE_UNTIL = "effectiveUntil"
@@ -168,3 +171,4 @@ PROP_TITLE = "title"
 PROP_TRAITS = "traits"
 PROP_TYPE = "type"
 PROP_UNITS = "units"
+PROP_USERNAME = "username"
